==================
django-allauth-cas
==================

.. image:: https://travis-ci.org/aureplop/django-allauth-cas.svg?branch=master
    :target: https://travis-ci.org/aureplop/django-allauth-cas

.. image:: https://coveralls.io/repos/github/aureplop/django-allauth-cas/badge.svg?branch=master
    :target: https://coveralls.io/github/aureplop/django-allauth-cas?branch=master


CAS support for django-allauth_.

Supports:

- Django 1.8-10 - Python 2.7, 3.4-5
- Django 1.11 - Python 2.7, 3.4-6


.. _django-allauth: https://www.intenct.nl/projects/django-allauth/
